@@ -7,11 +7,14 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/agent"
+	"github.com/superfly/flyctl/client"
+	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/env"
+	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/state"
 )
 
@@ -23,11 +26,22 @@ To continue interacting with Fly, the user will need to log in again.
 		short = "Logs out the currently logged in user"
 	)
 
-	return command.New("logout", short, long, runLogout,
-		command.RequireSession)
+	return command.New("logout", short, long, runLogout)
 }
 
 func runLogout(ctx context.Context) (err error) {
+	log := logger.FromContext(ctx)
+
+	if c := client.FromContext(ctx); c.Authenticated() {
+		resp, err := gql.LogOut(ctx, c.API().GenqClient)
+		if err != nil || !resp.LogOut.Ok {
+			log.Warnf("Unable to revoke token")
+		}
+		if err != nil {
+			log.Debug(err.Error())
+		}
+	}
+
 	var ac *agent.Client
 	if ac, err = agent.DefaultClient(ctx); err == nil {
 		if err = ac.Kill(ctx); err != nil {
