@@ -10,6 +10,7 @@ import (
 
 	"github.com/superfly/flyctl/flyctl"
 	"github.com/superfly/flyctl/internal/filemu"
+	"github.com/superfly/flyctl/wg"
 )
 
 // SetAccessToken sets the value of the access token at the configuration file
@@ -44,6 +45,18 @@ func SetAutoUpdate(path string, autoUpdate bool) error {
 	})
 }
 
+func SetWireGuardState(path string, state map[string]*wg.WireGuardState) error {
+	return set(path, map[string]interface{}{
+		WireGuardStateFileKey: state,
+	})
+}
+
+func SetWireGuardWebsocketsEnabled(path string, enabled bool) error {
+	return set(path, map[string]interface{}{
+		WireGuardWebsocketsFileKey: enabled,
+	})
+}
+
 // Clear clears the access token, metrics token, and wireguard-related keys of the configuration
 // file found at path.
 func Clear(path string) (err error) {
